package daca.service;

import javax.servlet.ServletContext;

import org.springframework.context.ApplicationContext;
import org.springframework.web.context.support.WebApplicationContextUtils;

import daca.dao.GerenteBanco;
import daca.util.DCContants;
import daca.util.FacesUtils;

/**
 * The implementation of <code>ServiceLocator</code>.
 * <p>
 * This class is managed by the JSF managed bean facility,
 * and is set with application scope.
 * 
 * @see ServiceLocator
 */
public class ServiceLocator {

	
	//the Spring application context
	private ApplicationContext appContext;
	
	//the cached user service
	private GerenteBanco persistentService;
	
	/**
	 * Constructor.
	 * <p>
	 * The following steps being done:
	 * <ul>
	 * <li>retrieve Spring application context from servlet context.
	 * <li>look up <code>UserService</code> from Spring applicatino context.
	 * </ul>
	 */
	public ServiceLocator() {
		ServletContext context = FacesUtils.getServletContext();
		this.appContext = WebApplicationContextUtils.getRequiredWebApplicationContext(context);
		persistentService = (GerenteBanco)this.lookupService(DCContants.PERSISTENT_SERVICE_BEAN_NAME);		
	}
	
	/**
	 * Lookup service based on service bean name.
	 * 
	 * @param serviceBeanName the service bean name
	 * @return the service bean
	 */
	public Object lookupService(String serviceBeanName) {
		return appContext.getBean(serviceBeanName);
	}
	
	
	public GerenteBanco getPersistentService() {
		return persistentService;
	}
	public void setPersistentService(GerenteBanco persistentService) {
		this.persistentService = persistentService;
	}
}
